@@ -71,6 +71,15 @@ class Client(object):
     def invoice_delete(self, id):
         return self.call('invoice_delete', id = id)
 
+    def invoice_add_item(self, **kw):
+        return self.call('invoice_add_item', **kw)
+
+    def invoice_remove_item(self, **kw):
+        return self.call('invoice_remove_item', **kw)
+
+    def invoice_list_items(self, **kw):
+        return self.call('invoice_list_items', **kw)
+
     def customer_add(self, **kw):
         return self.call('customer_add', **kw)
 
